#
# spec file for package python-scrypt
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-scrypt
Version:        0.8.27
Release:        1.2
Summary:        Bindings for scrypt
License:        BSD-2-Clause
URL:            https://github.com/holgern/py-scrypt
Source0:        https://files.pythonhosted.org/packages/source/s/scrypt/scrypt-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(openssl)
%python_subpackages

%description
Bindings for the scrypt key derivation function library.

%prep
%setup -q -n scrypt-%{version}
dos2unix -R README.rst scrypt/*.py
sed -i '1{/^#!/ d}' scrypt/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%pyunittest_arch discover -s scrypt/tests -v

%files %{python_files}
%doc README.rst
%license LICENSE
%pycache_only %{python_sitearch}/scrypt/__pycache__
%{python_sitearch}/_scrypt*.so
%{python_sitearch}/scrypt/
%{python_sitearch}/scrypt-%{version}-py%{python_version}.egg-info

%changelog
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.27:
  * CI fixes
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 0.8.24:
  * Support building on MSYS2
  * Support building for MSYS2 environments
* Fri Jun  9 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Sat Jun  4 2022 Dirk Müller <dmueller@suse.com>
- update to 0.8.20:
  * Fix #8 by adding missing gettimeofday.c to MANIFEST.in
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 0.8.19:
  * Use RtlGenRandom instead of CryptGenRandom on windows
  * Add check for c:\Program Files\OpenSSL-Win64 and c:\Program Files\OpenSSL-Win32
* Thu Jun 17 2021 Dirk Müller <dmueller@suse.com>
- update to 0.8.18:
  * add wheel for python 3.9
* Sun Jan 17 2021 Benjamin Greiner <code@bnavigator.de>
- Fix test call (the old non-macro pytest call did conflict with
  _build directories from other python3 flavors)
- Fix line endings and remove interpreter lines in sitelib
* Tue Dec  1 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.8.17:
  * add_dll_directory for python 3.8 on windows, as importlib.util.find_spec does not search all paths anymore
  * Add additional test vector from RFC
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.8.15:
  * Fix missing import
  * fix imp deprecation warning
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Thu Mar 28 2019 pgajdos@suse.com
- version update to 0.8.13
  * improve build for conda forge
  * Add SCRYPT_WINDOWS_LINK_LEGACY_OPENSSL environment variable,
    when set, openssl 1.0.2 is linked
  * fix build for conda feedstock
  * use the static libcrypto_static for windows and openssl 1.1.1
- enable testsuite
- package LICENSE
* Mon Dec 10 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 0.8.6:
  No changelog provided
* Sat Apr 22 2017 aloisio@gmx.com
- Initial package (0.8.0)
